@@ -21,6 +21,7 @@
 
 #define __EV_EVINCE_DOCUMENT_H_INSIDE__
 
+#include <libdocument/ev-annotation.h>
 #include <libdocument/ev-async-renderer.h>
 #include <libdocument/ev-attachment.h>
 #include <libdocument/ev-backends-manager.h>
@@ -37,7 +38,6 @@
 #include <libdocument/ev-document-links.h>
 #include <libdocument/ev-document-misc.h>
 #include <libdocument/ev-document-security.h>
-#include <libdocument/ev-document-thumbnails.h>
 #include <libdocument/ev-document-transition.h>
 #include <libdocument/ev-document-type-builtins.h>
 #include <libdocument/ev-file-exporter.h>
@@ -49,6 +49,7 @@
 #include <libdocument/ev-link-action.h>
 #include <libdocument/ev-link-dest.h>
 #include <libdocument/ev-link.h>
+#include <libdocument/ev-mapping-list.h>
 #include <libdocument/ev-page.h>
 #include <libdocument/ev-render-context.h>
 #include <libdocument/ev-selection.h>
